netapp_ontap.models.shelf_ports API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_ports`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfPortsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cable GET POST PATCH`

    The cable field of the shelf_ports.

  `designator GET POST PATCH`

    The designator field of the shelf_ports.

    Valid choices:

    - circle
    - square
    - 1
    - 2
    - 3
    - 4
  `id GET POST PATCH`

    The id field of the shelf_ports.

    Example: 0

  `internal GET POST PATCH`

    The internal field of the shelf_ports.

  `mac_address GET POST PATCH`

    The mac_address field of the shelf_ports.

  `module_id GET POST PATCH`

    The module_id field of the shelf_ports.

    Valid choices:

    - a
    - b
  `remote GET POST PATCH`

    The remote field of the shelf_ports.

  `state GET POST PATCH`

    The state field of the shelf_ports.

    Valid choices:

    - connected
    - disconnected
    - error
  `wwn GET POST PATCH`

    The wwn field of the shelf_ports.

    Example: 500A0980000B6C3F